summaryrefslogtreecommitdiffstats
path: root/generic/tclInterp.c
diff options
context:
space:
mode:
authorandreas_kupries <akupries@shaw.ca>2008-07-21 19:38:09 (GMT)
committerandreas_kupries <akupries@shaw.ca>2008-07-21 19:38:09 (GMT)
commitee9aa214c65a48c44f14e0b78ea877cb7c8ea28f (patch)
tree496a640f3a50041bbfbbababc8dcd88e0d08d729 /generic/tclInterp.c
parent5784ef17a727e040f9964e60b26b181df02c47d2 (diff)
downloadtcl-ee9aa214c65a48c44f14e0b78ea877cb7c8ea28f.zip
tcl-ee9aa214c65a48c44f14e0b78ea877cb7c8ea28f.tar.gz
tcl-ee9aa214c65a48c44f14e0b78ea877cb7c8ea28f.tar.bz2
* generic/tclBasic.c: Extended the existing TIP #280 system (info
* generic/tclCmdAH.c: frame), added the ability to track the * generic/tclCompCmds.c: absolute location of literal procedure * generic/tclCompile.c: arguments, and making this information * generic/tclCompile.h: available to uplevel, eval, and * generic/tclInterp.c: siblings. This allows proper tracking of * generic/tclInt.h: absolute location through custom (Tcl-coded) * generic/tclNamesp.c: control structures based on uplevel, etc. * generic/tclProc.c:
Diffstat (limited to 'generic/tclInterp.c')
-rw-r--r--generic/tclInterp.c10
1 files changed, 7 insertions, 3 deletions
diff --git a/generic/tclInterp.c b/generic/tclInterp.c
index 78772bd..67a031a 100644
--- a/generic/tclInterp.c
+++ b/generic/tclInterp.c
@@ -10,7 +10,7 @@
* See the file "license.terms" for information on usage and redistribution
* of this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tclInterp.c,v 1.83.2.1 2008/06/20 19:23:25 dgp Exp $
+ * RCS: @(#) $Id: tclInterp.c,v 1.83.2.2 2008/07/21 19:38:19 andreas_kupries Exp $
*/
#include "tclInt.h"
@@ -2472,11 +2472,15 @@ SlaveEval(
if (objc == 1) {
/*
* TIP #280: Make invoker available to eval'd script.
*/
Interp *iPtr = (Interp *) interp;
- result = TclEvalObjEx(slaveInterp, objv[0], 0, iPtr->cmdFramePtr, 0);
+ CmdFrame* invoker = iPtr->cmdFramePtr;
+ int word = 0;
+
+ TclArgumentGet (interp, objv[0], &invoker, &word);
+ result = TclEvalObjEx(slaveInterp, objv[0], 0, invoker, word);
} else {
objPtr = Tcl_ConcatObj(objc, objv);
Tcl_IncrRefCount(objPtr);
@@ -2472,11 +2472,15 @@ SlaveEval(
if (objc == 1) {
/*
- * TIP #280: Make invoker available to eval'd script.
+ * TIP #280: Make actual argument location available to eval'd script.
*/
Interp *iPtr = (Interp *) interp;